<?php
namespace Ep\TecDoc\Hydrator;

use Interop\Container\ContainerInterface;
use Laminas\Hydrator\HydratorInterface;
use Laminas\Hydrator\HydratorPluginManager;
use Laminas\Hydrator\ReflectionHydrator;
use Laminas\Hydrator\Strategy\ClosureStrategy;
use Laminas\ServiceManager\Factory\FactoryInterface;

/**
 * Class AbstractRecordSeqHydratorFactory
 *
 * @package Ep\TecDoc\Hydrator
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/tecdoc
 */
class AbstractRecordSeqHydratorFactory implements FactoryInterface
{
    /**
     * Create an object
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return HydratorInterface
     * @throws \Exception
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        /** @var HydratorPluginManager $hydrators */
        $hydrators = $container->get(HydratorPluginManager::class);

        $hydrator = new ReflectionHydrator();
        $recordClass = preg_replace('#Seq\\\?#', '', $requestedName);

        if (!$hydrators->has($recordClass)) {
            throw new \RuntimeException(sprintf(
                'Nemam hidrator za record %s',
                $recordClass
            ));
        }

        /** @var HydratorInterface $recordHydrator */
        $recordHydrator = $hydrators->get($recordClass);

        $hydrator->addStrategy('array', new ClosureStrategy(
            function() { return []; },
            function($records) use ($recordHydrator, $recordClass) {
                $hydrated = [];

                if (is_array($records)) {
                    foreach ($records as $record) {
                        $hydrated[] = $recordHydrator->hydrate($record, new $recordClass());
                    }
                }

                return $hydrated;
            }
        ));

        return $hydrator;
    }
}
