<?php
namespace Ep\TecDoc\Hydrator;

use Interop\Container\ContainerInterface;
use Laminas\Hydrator\HydratorInterface;
use Laminas\Hydrator\HydratorPluginManager;
use Laminas\Hydrator\ReflectionHydrator;
use Laminas\Hydrator\Strategy\ClosureStrategy;
use Laminas\ServiceManager\Factory\FactoryInterface;

/**
 * Class AbstractResponseHydratorFactory
 *
 * @package Ep\TecDoc\Hydrator
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/tecdoc
 */
class AbstractResponseHydratorFactory implements FactoryInterface
{
    /**
     * Create an object
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return object
     *
     * @throws \Exception
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        /** @var HydratorPluginManager $hydrators */
        $hydrators = $container->get(HydratorPluginManager::class);

        $hydrator = new ReflectionHydrator();

        $recordSeqClass = preg_replace('#Response#', 'Record', $requestedName);
        $recordSeqClass = preg_replace('#Record\\\#', 'Record\Seq\\', $recordSeqClass) . 'Seq';

        if (!$hydrators->has($recordSeqClass)) {
            throw new \RuntimeException(sprintf(
                'Ne mogu pronaći hidrator za seq klasu %s',
                $recordSeqClass
            ));
        }

        /** @var HydratorInterface $recordSeqHydrator */
        $recordSeqHydrator = $hydrators->get($recordSeqClass);

        $hydrator->addStrategy('data', new ClosureStrategy(
            function() { return []; },
            function($data) use ($recordSeqClass, $recordSeqHydrator) {
                return $recordSeqHydrator->hydrate($data, new $recordSeqClass());
            }
        ));

        return $hydrator;
    }
}
