<?php
namespace Ep\TecDoc\Middleware;

use Ep\TecDoc\TecDoc;
use Psr\Container\ContainerInterface;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;
use Laminas\Diactoros\Response\TextResponse;
use Laminas\Stratigility\MiddlewarePipe;
use Laminas\Stratigility\MiddlewarePipeInterface;
use function Laminas\Stratigility\path;
use Laminas\View\Renderer\RendererInterface;

class VehicleSelect implements MiddlewarePipeInterface
{
    /** @var ContainerInterface */
    protected $container;
    /** @var MiddlewarePipeInterface */
    protected $pipeline;

    /**
     * VehicleSelect constructor.
     *
     * @param TecDoc $tecdoc
     * @param RendererInterface $renderer
     */
    public function __construct(ContainerInterface $container)
    {
        $this->container = $container;
        $this->pipeline = new MiddlewarePipe();

        $tecdoc = $container->get('tecdoc_service');
        $renderer = $container->get(RendererInterface::class);

        $this->pipeline->pipe(path('/manufacturers', new VehicleSelect\Manufacturers($tecdoc, $renderer)));
        $this->pipeline->pipe(path('/models', new VehicleSelect\Models($tecdoc, $renderer)));
        $this->pipeline->pipe(path('/vehicles', new VehicleSelect\Vehicles($tecdoc, $renderer)));
        $this->pipeline->pipe(new VehicleSelect\Index($tecdoc, $renderer));
    }

    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        return $this->pipeline->process($request, $handler);
    }

    public function pipe(MiddlewareInterface $middleware): void
    {
        $this->pipeline->pipe($middleware);
    }

    public function handle(ServerRequestInterface $request): ResponseInterface
    {
        return $this->pipeline->handle($request);
    }
}
