<?php
namespace Ep\TecDoc\Middleware\VehicleSelect;

use Ep\TecDoc\TecDocInterface;
use Ep\View\Renderer\TwigRenderer;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;
use Laminas\Diactoros\Response\HtmlResponse;
use Laminas\Diactoros\Response\RedirectResponse;
use Laminas\View\Renderer\RendererInterface;

/**
 * Class Index
 *
 * @package Ep\TecDoc\Middleware\VehicleSelect
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/tecdoc
 */
class Index implements MiddlewareInterface
{
    /** @var TecDocInterface */
    protected $tecdoc;
    /** @var RendererInterface|TwigRenderer */
    protected $renderer;

    /**
     * Index constructor.
     *
     * @param TecDocInterface $tecdoc
     * @param RendererInterface $renderer
     */
    public function __construct(TecDocInterface $tecdoc, RendererInterface $renderer)
    {
        $this->tecdoc = $tecdoc;
        $this->renderer = $renderer;
    }

    /**
     * Process an incoming server request and return a response, optionally delegating
     * response creation to a handler.
     *
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     *
     * @return ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        if ('POST' === $request->getMethod()) {
            if ($response = $this->processPost($request)) {
                return $response;
            }
        }

        return new HtmlResponse(
            $this->renderer->render('@tecdoc/vehicle-select/index.html.twig', [
                'current' => $this->tecdoc->getCurrentVehicle(),
            ])
        );
    }

    /**
     * Obrađuje POST request.
     *
     * @param ServerRequestInterface $request
     *
     * @return ResponseInterface
     */
    protected function processPost(ServerRequestInterface $request): ?ResponseInterface
    {
        $config = $this->tecdoc->getConfig();
        $post = $request->getParsedBody();

        $vehicle = $this->tecdoc->getVehicleById(intval($post['vehicle']));

        if ($vehicle) {
            $this->tecdoc->setCurrentVehicle($vehicle);
            $slug = $vehicle->getSlug();

            $url = sprintf('/%s/%s', $slug, ltrim($config['catalog_url'], '/'));

            /** @var callable $baseUrl */
            $baseUrl = $this->renderer->plugin('base_url');
            $url = $baseUrl($url);

            return new RedirectResponse($url);
        }

        return null;
    }
}
