<?php
namespace Ep\TecDoc\Middleware\VehicleSelect;

use Ep\TecDoc\TecDoc;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;
use Laminas\Diactoros\Response\HtmlResponse;
use Laminas\Diactoros\Response\TextResponse;
use Laminas\View\Renderer\RendererInterface;

/**
 * Class Manufacturers
 *
 * @package Ep\TecDoc\Middleware\VehicleSelect
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/tecdoc
 */
class Manufacturers implements MiddlewareInterface
{
    /** @var TecDoc */
    protected $tecdoc;
    /** @var RendererInterface */
    protected $renderer;

    /**
     * Manufacturers constructor.
     *
     * @param TecDoc $tecdoc
     * @param RendererInterface $renderer
     */
    public function __construct(TecDoc $tecdoc, RendererInterface $renderer)
    {
        $this->tecdoc   = $tecdoc;
        $this->renderer = $renderer;
    }

    /**
     * Process an incoming server request and return a response, optionally delegating
     * response creation to a handler.
     *
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     *
     * @return ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        $featured = $this->tecdoc->getFeaturedManufacturers();
        $manufacturers = $this->tecdoc->getManufacturers();

        return new HtmlResponse(
            $this->renderer->render('@tecdoc/vehicle-select/manufacturers.html.twig', [
                'featured' => $featured,
                'manufacturers' => $manufacturers,
            ])
        );
    }
}
