<?php
namespace Ep\TecDoc\Middleware\VehicleSelect;

use Ep\TecDoc\TecDoc;
use Ep\TecDoc\TecDocInterface;
use Psr\Container\ContainerInterface;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;
use Laminas\Diactoros\Response\HtmlResponse;
use Laminas\Diactoros\Response\TextResponse;
use Laminas\View\Renderer\RendererInterface;

/**
 * Class Models
 *
 * @package Ep\TecDoc\Middleware\VehicleSelect
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/tecdoc
 */
class Models implements MiddlewareInterface
{
    /** @var TecDoc */
    protected $tecdoc;
    /** @var RendererInterface */
    protected $renderer;

    /**
     * Models constructor.
     *
     * @param TecDoc $tecdoc
     * @param RendererInterface $renderer
     */
    public function __construct(TecDoc $tecdoc, RendererInterface $renderer)
    {
        $this->tecdoc   = $tecdoc;
        $this->renderer = $renderer;
    }

    /**
     * Process an incoming server request and return a response, optionally delegating
     * response creation to a handler.
     *
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     *
     * @return ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        $path = $request->getUri()->getPath();

        if (!preg_match('#^/(\d+)$#', $path, $matches)) {
            throw new \RuntimeException('Neispravan ili nepostojeći ID proizvođača.');
        }

        $manufacturerId = intval($matches[1]);

        $models = $this->tecdoc->getModelSeries($manufacturerId);

        return new HtmlResponse(
            $this->renderer->render('@tecdoc/vehicle-select/models.html.twig', [
                'models' => $models,
            ])
        );
    }
}
