<?php
namespace Ep\TecDoc\Middleware\VehicleSelect;

use Ep\TecDoc\TecDoc;
use Ep\TecDoc\TecDocInterface;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;
use Laminas\Diactoros\Response\HtmlResponse;
use Laminas\Diactoros\Response\TextResponse;
use Laminas\View\Renderer\RendererInterface;

/**
 * Class Vehicles
 *
 * @package Ep\TecDoc\Middleware\VehicleSelect
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/tecdoc
 */
class Vehicles implements MiddlewareInterface
{
    /** @var TecDoc|TecDocInterface */
    protected $tecdoc;
    /** @var RendererInterface */
    protected $renderer;

    /**
     * Vehicles constructor.
     *
     * @param TecDoc $tecdoc
     * @param RendererInterface $renderer
     */
    public function __construct(TecDoc $tecdoc, RendererInterface $renderer)
    {
        $this->tecdoc   = $tecdoc;
        $this->renderer = $renderer;
    }

    /**
     * Process an incoming server request and return a response, optionally delegating
     * response creation to a handler.
     *
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     *
     * @return ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        $path = $request->getUri()->getPath();

        if (!preg_match('#/(\d+)/(\d+)$#', $path, $matches)) {
            throw new \RuntimeException('Neispravan ID proizvođača ili modela.');
        }

        $manufacturerId = intval($matches[1]);
        $modelId = intval($matches[2]);

        $vehicles = $this->tecdoc->getVehicles($manufacturerId, $modelId);
        $grouped = [];

        foreach ($vehicles as $vehicle) {
            $grouped[$vehicle->getMotorType()][] = $vehicle;
        }

        return new HtmlResponse(
            $this->renderer->render('@tecdoc/vehicle-select/vehicles.html.twig', [
                'grouped' => $grouped,
            ])
        );
    }
}
