<?php
namespace Ep\TecDoc\Plugin;

use Ak\Wp\Plugin\PluginInterface;
use Ep\TecDoc\TecDoc;

/**
 * Class TecDocCategory
 *
 * @package Ep\TecDoc\Plugin
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/tecdoc
 */
class TecDocCategory implements PluginInterface
{
    /** @var TecDoc */
    private $tecdoc;
    /** @noinspection PhpMissingParentConstructorInspection */

    /**
     * TecDocCategory constructor.
     * @param TecDoc $tecdoc
     */
    public function __construct(TecDoc $tecdoc)
    {
        $this->tecdoc = $tecdoc;
    }

    public function attach(): void
    {
        add_filter('term_link', [$this, 'term_link'], 10, 3);
    }

    public function term_link($url, /** @noinspection PhpUnusedParameterInspection */$term, $taxonomy)
    {
        if ($taxonomy === 'product_cat' && ($vehicle = $this->tecdoc->getCurrentVehicle())) {
            $homeUrl = rtrim(home_url(), '/');

            if (empty($homeUrl)) {
                $url = '/' . $vehicle->getSlug() . '/' . ltrim($url, '/');
            } else {
                $url = str_replace($homeUrl, $homeUrl . '/' . $vehicle->getSlug(), $url);
            }
        }

        return $url;
    }
}