<?php
namespace Ep\TecDoc\Request;

/**
 * Class AbstractRequest
 *
 * @package Ep\TecDoc\Request
 * @author  Elektronika Perhoč <web@ep.hr>
 * @link    http://gitlab.ep.local/ep-framework/core
 */
abstract class AbstractRequest implements RequestInterface
{
    /** @var string */
    protected $responseClass;
    /** @var string */
    protected $remoteFunctionName;
    /** @var int */
    protected $provider;

    /**
     * AbstractRequest constructor.
     *
     * @param int $provider
     */
    public function __construct(int $provider = null)
    {
        $this->provider = $provider;
    }

    /**
     * @return string
     */
    public function getResponseClass(): string
    {
        if (null === $this->responseClass) {
            throw new \RuntimeException('Klasa TecDoc responsea mora biti postavljana u child klasi.');
        }

        return $this->responseClass;
    }

    /**
     * @return string
     */
    public function getRemoteFunctionName(): string
    {
        if (null === $this->remoteFunctionName) {
            throw new \RuntimeException('Ime remote funkcije mora biti postavljeno u child klasi.');
        }

        return $this->remoteFunctionName;
    }

    /**
     * @return int
     */
    public function getProvider(): ?int
    {
        return $this->provider;
    }

    /**
     * @param int $provider
     */
    public function setProvider(int $provider): void
    {
        $this->provider = $provider;
    }

    /**
     * @return array
     */
    public function toArray(): array
    {
        $array = [];

        foreach (get_object_vars($this) as $name => $value) {
            if (
                in_array($name, ['responseClass', 'remoteFunctionName']) ||
                null === $value
            ) continue;

            if ($value instanceof RequestInterface) {
                $value = $value->toArray();
            }

            $array[$name] = is_array($value) ? ['array' => $value] : $value;
        }

        return $array;
    }
}