<?php
namespace Ep\TecDoc;

use Ep\Http\AbstractHttpClientFactory;
use GuzzleHttp\Client;
use Interop\Container\ContainerInterface;
use Symfony\Component\Cache\Adapter\NullAdapter;
use Laminas\Hydrator\HydratorPluginManager;
use Laminas\ServiceManager\Factory\FactoryInterface;

/**
 * Class TecDocFactory
 *
 * @package Ep\TecDoc
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/tecdoc
 */
class TecDocFactory implements FactoryInterface
{
    /**
     * Create an object
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return object
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $app = $container->get('config')['app'] ?? [];
        $config = $container->get('config')['tecdoc'] ?? [];

        $cache = ($app['development'] ?? false)
            ? new NullAdapter()
            : $container->get('cache.tecdoc');

        $httpFactory = new AbstractHttpClientFactory();

        $http = $httpFactory($container, '', [
            'base_uri' => TecDoc::SERVICE_BASE_URI,
            'timeout' => $config['http_timeout'] ?? 2,
            'cache' => $cache,
            'headers' => [
                'Content-Type' => 'application/json',
            ],
        ]);


        $hydrators = $container->get(HydratorPluginManager::class);
        $session = $container->get('tecdoc_session');

        return new TecDoc($config, $http, $cache, $hydrators, $session);
    }
}
